@@ -62,28 +62,28 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "alloc_8h.html",
-"group__pw__client.html#gaffa5b807a9674495aa5c14a68d5fd88c",
-"group__pw__global.html#gae35b9eb5ebbdead2e5a79845d5fa2031",
-"group__pw__keys.html#gaa2674ee0552a3f30a0446eb0461741d6",
-"group__pw__node.html#ga3db541c9ec1c2245fe17402135979f2d",
-"group__pw__session__manager.html#ga2de263210f215bfe195aa672b33168d3",
-"group__pwtest.html#ga1f365422ab4403a3f3799b3667e01ff4",
-"group__spa__cpu.html#gade1463bb6f0e53ab480be27ac0b4383c",
-"group__spa__json.html#ga8e5fa24c312810edffc063169e55497d",
-"group__spa__names.html#gaea2a7f9455eba0d3fb89870950c0c94d",
-"group__spa__param.html#ga4b41f63cb5b094caa8fa328bdac052e5",
-"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0a871dcd85dad60d460bbad9176d23d048",
-"group__spa__param.html#gga9c37ad62772233835d6bf5083a9e4613ad6dae916837199443be552bd7e8f1fa8",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43eadeda74b6a7caa8d6d795177202601142",
-"group__spa__pod.html#gabc8a77a767e20163e368ed09ab01f527",
-"group__spa__utils__defs.html#ga3bca1a11d1c7e8404f9456580acf0676",
-"page_objects_design.html#autotoc_md72",
-"structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392",
-"structpw__impl__module__events.html#a1f0de76c49fdf742fe40c6fc0799d08c",
-"structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7",
-"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0",
-"structspa__meta__header.html#a1410208fd9ccdd153418f01d5ce12d7b",
-"structspa__system__methods.html#ada4083f64959db28b4a03f4032ee87e9"
+"group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
+"group__pw__global.html#gab6796dae933803798be1658f4020315c",
+"group__pw__keys.html#gaa039c0a911742213e239311ec73b623b",
+"group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f",
+"group__pw__session__manager.html#ga1df3e3242c1438fe35c454dd3ed41219",
+"group__pwtest.html#ga135297caa69f5e14b2b20148850d080b",
+"group__spa__cpu.html#gad4c6b81675ec1a16c23239041970f099",
+"group__spa__json.html#ga6d871debd28993273c3cbb1b0f7fce64",
+"group__spa__names.html#gadc887e81536271d1538500da0fb6be1f",
+"group__spa__param.html#ga49c3cb2109aab971f92dfe13bde3759b",
+"group__spa__param.html#gga3338e5f0867a0e073d8dcfd309fe8850a682778cce4e3c92fa38ba77e8f838246",
+"group__spa__param.html#gga9c37ad62772233835d6bf5083a9e4613a3c01bfb4218e827d2d2f21385d71798e",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43eaa9b46794cf9585c21b7880d238ce2355",
+"group__spa__pod.html#gab23072b3f0f817478e011658b3504161",
+"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84",
+"page_module_roc_sink.html",
+"structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254",
+"structpw__impl__link__events.html",
+"structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97",
+"structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3",
+"structspa__loop__utils__methods.html#acb650a30486b87fcab5859afd000d913",
+"structspa__strbuf.html#ac82fdbc33669185a77140a3faf908a0c"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
