@@ -1,5 +1,23 @@
 var NAVTREEINDEX17 =
 {
+"structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254":[10,4,3,2,1],
+"structpw__client__events.html#af685647fe57d1a9dba2a0d89d32aae39":[10,4,3,2,2],
+"structpw__client__info.html":[10,4,3,1],
+"structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21":[10,4,3,1,0],
+"structpw__client__info.html#a9123521af948ea7b720d1ebb0f39c66b":[10,4,3,1,1],
+"structpw__client__methods.html":[10,4,3,3],
+"structpw__client__methods.html#a17155250b4b575de0530a8d01447148a":[10,4,3,3,3],
+"structpw__client__methods.html#a2804d8a526c068a486a4e261821c9a07":[10,4,3,3,5],
+"structpw__client__methods.html#a298f33a5d81477d06b08f52d233b740a":[10,4,3,3,2],
+"structpw__client__methods.html#a7af9e64e81ebc0b3a7d726ff98e0dd84":[10,4,3,3,4],
+"structpw__client__methods.html#a898d61fc799b5c09421365854020b357":[10,4,3,3,0],
+"structpw__client__methods.html#ad5cf20929a275ce91d7fdbbb80e70be3":[10,4,3,3,1],
+"structpw__client__node.html":[10,7,0,4],
+"structpw__client__node__buffer.html":[10,7,0,1],
+"structpw__client__node__buffer.html#a003e6b6549d0dbd9e2c8a6030a1cfa85":[10,7,0,1,2],
+"structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392":[10,7,0,1,0],
+"structpw__client__node__buffer.html#a1d524a38ed82fb88371d741bcb1e3ff0":[10,7,0,1,1],
+"structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3":[10,7,0,1,3],
 "structpw__client__node__events.html":[10,7,0,2],
 "structpw__client__node__events.html#a0942c754a0fd77db7c9051172b2ac991":[10,7,0,2,10],
 "structpw__client__node__events.html#a0fdb140f41117e7690aca449844d72c2":[10,7,0,2,9],
@@ -38,8 +56,8 @@ var NAVTREEINDEX17 =
 "structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87":[10,4,2,1,2],
 "structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c":[10,4,2,1,0],
 "structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[10,4,2,1,3],
-"structpw__control.html":[10,5,8,4],
 "structpw__control.html":[10,5,10,2],
+"structpw__control.html":[10,5,8,4],
 "structpw__control__events.html":[10,5,10,1],
 "structpw__control__events.html#a2cda9616fd4aa65d7cc2f8dc6efe69dc":[10,5,10,1,4],
 "structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,5,10,1,0],
@@ -52,6 +70,7 @@ var NAVTREEINDEX17 =
 "structpw__core__events.html#a28cd6e2263efb69df702822028a45df2":[10,4,4,2,8],
 "structpw__core__events.html#a590bf80a38429eef4a94d2e8b7f82e56":[10,4,4,2,4],
 "structpw__core__events.html#a7c1f8bd6078afab78aa943704efe7131":[10,4,4,2,7],
+"structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e":[10,4,4,2,9],
 "structpw__core__events.html#a8433a5ea5115e8d914a70ba5dacd3b81":[10,4,4,2,1],
 "structpw__core__events.html#a8a700a03453729d52d96112647125303":[10,4,4,2,5],
 "structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7":[10,4,4,2,0],
@@ -229,25 +248,6 @@ var NAVTREEINDEX17 =
 "structpw__impl__factory__implementation.html":[10,5,3,2],
 "structpw__impl__factory__implementation.html#a99eef2345bd7b402f47ad72beb6ebfe7":[10,5,3,2,1],
 "structpw__impl__factory__implementation.html#ab63e939995687efd690f736730021e7f":[10,5,3,2,0],
-"structpw__impl__link.html":[10,5,8,3],
 "structpw__impl__link.html":[10,5,4,2],
-"structpw__impl__link__events.html":[10,5,4,1],
-"structpw__impl__link__events.html#a05b20c99f1014e62e0d032b92382f584":[10,5,4,1,5],
-"structpw__impl__link__events.html#a05c9fec1c6580f673d09e33005bca5ee":[10,5,4,1,0],
-"structpw__impl__link__events.html#a36d3179004ca94bfe99cfc7c7608321a":[10,5,4,1,4],
-"structpw__impl__link__events.html#a7cf5965ff2f975aba7ac061938e1fa9c":[10,5,4,1,2],
-"structpw__impl__link__events.html#a8e6dceaefdbbe793d1eba749370a3f25":[10,5,4,1,1],
-"structpw__impl__link__events.html#ad161d67256c9fd29f54cc53dbacb10d5":[10,5,4,1,6],
-"structpw__impl__link__events.html#ae136867ff703e789d52dbb2ef427726d":[10,5,4,1,3],
-"structpw__impl__metadata.html":[10,5,5,2],
-"structpw__impl__metadata__events.html":[10,5,5,1],
-"structpw__impl__metadata__events.html#a1f7feaad034d62902dccdef0a2b2f85a":[10,5,5,1,1],
-"structpw__impl__metadata__events.html#a2a0419974291d4e9360544e5618ffb0f":[10,5,5,1,3],
-"structpw__impl__metadata__events.html#a75ce933b493a16ecad3e8f9834cc74e6":[10,5,5,1,2],
-"structpw__impl__metadata__events.html#ac11ef017d8f59e0a28d1d882ac508b22":[10,5,5,1,0],
-"structpw__impl__module.html":[10,5,6,2],
-"structpw__impl__module__events.html":[10,5,6,1],
-"structpw__impl__module__events.html#a1f0de76c49fdf742fe40c6fc0799d08c":[10,5,6,1,3],
-"structpw__impl__module__events.html#a2cb2abff60d0fa2370afcb8b5c2ae830":[10,5,6,1,2],
-"structpw__impl__module__events.html#a4cfcceec669bbbdf6697e36cd5dbae1d":[10,5,6,1,1]
+"structpw__impl__link.html":[10,5,8,3]
 };
