@@ -1,18 +1,43 @@
 var NAVTREEINDEX20 =
 {
+"structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3":[10,8,4,7,2],
+"structspa__device__events.html#a5b83e45fd5922657978cc36df24cc1c7":[10,8,4,7,3],
+"structspa__device__events.html#a64cea4459b8c4a483d0a2dd684f3e132":[10,8,4,7,1],
+"structspa__device__events.html#a830fadb39e2a8658f9b4cb663619cf4b":[10,8,4,7,4],
+"structspa__device__events.html#ad79a5bdce6b6bd7b299baa38330c96a7":[10,8,4,7,0],
+"structspa__device__info.html":[10,8,4,4],
+"structspa__device__info.html#a2692374f54a8d9f743474c4a3fcb8ebc":[10,8,4,4,2],
+"structspa__device__info.html#a2ef8690873a8db10e6c29357ea4a216c":[10,8,4,4,3],
+"structspa__device__info.html#a394aa2b1d356ce8e510330aedd38ff63":[10,8,4,4,0],
+"structspa__device__info.html#a5184282839436a8b87d505b4b17cffbd":[10,8,4,4,4],
+"structspa__device__info.html#afbe429acf565ab384929f0ccf76fc49c":[10,8,4,4,1],
+"structspa__device__methods.html":[10,8,4,8],
+"structspa__device__methods.html#a232006e407b2abdb2450a440172186ee":[10,8,4,8,0],
+"structspa__device__methods.html#a25f49777c2e75988cd5fd7fc490479c8":[10,8,4,8,2],
+"structspa__device__methods.html#a3c9741ff5de62f38f2e3eca50ae24a10":[10,8,4,8,3],
+"structspa__device__methods.html#aa5bfc95e88b2f018dddc55fb64899215":[10,8,4,8,4],
+"structspa__device__methods.html#aac8a0ceced3319473ab3edd4271e1d64":[10,8,4,8,1],
+"structspa__device__object__info.html":[10,8,4,5],
+"structspa__device__object__info.html#a0758afd0518197c48d5d76cdc14526e3":[10,8,4,5,0],
+"structspa__device__object__info.html#a4ed767ff310d6f2e1d4cd78f3a7c3f6f":[10,8,4,5,1],
+"structspa__device__object__info.html#a702111c5873243c93551073552863666":[10,8,4,5,3],
+"structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1":[10,8,4,5,2],
+"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0":[10,8,4,5,4],
+"structspa__dict.html":[10,8,8,2,2],
+"structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0":[10,8,8,2,2,2],
 "structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399":[10,8,8,2,2,1],
 "structspa__dict.html#a88aca003fcdbc47599ffb3e2737f1a69":[10,8,8,2,2,0],
 "structspa__dict__item.html":[10,8,8,2,1],
 "structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a":[10,8,8,2,1,0],
 "structspa__dict__item.html#af08479e3ff870039be002b436a02457d":[10,8,8,2,1,1],
-"structspa__dll.html":[11,0,178],
-"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,178,2],
-"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,178,1],
-"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,178,6],
-"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,178,3],
-"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,178,4],
-"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,178,0],
-"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,178,5],
+"structspa__dll.html":[11,0,179],
+"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,179,2],
+"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,179,1],
+"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,179,6],
+"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,179,3],
+"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,179,4],
+"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,179,0],
+"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,179,5],
 "structspa__event.html":[10,8,0,15],
 "structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb":[10,8,0,15,1],
 "structspa__event.html#a2411141eed88d3587687a8d86c99d488":[10,8,0,15,0],
@@ -90,6 +115,7 @@ var NAVTREEINDEX20 =
 "structspa__io__buffers.html#a1364df7bc201533525e5a4fa54f444fe":[10,8,6,6,0],
 "structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b":[10,8,6,6,1],
 "structspa__io__clock.html":[10,8,6,9],
+"structspa__io__clock.html#a02274245ac560717fc5c06ddc66553ff":[10,8,6,9,9],
 "structspa__io__clock.html#a3242b88552347adc2e406b75f8136060":[10,8,6,9,8],
 "structspa__io__clock.html#a4813e6c9101d56eb1f3ac2e9eda1d8c8":[10,8,6,9,4],
 "structspa__io__clock.html#a726264b491673c896b53038752149ecb":[10,8,6,9,2],
@@ -97,9 +123,11 @@ var NAVTREEINDEX20 =
 "structspa__io__clock.html#aaddd01ce3e78da42c39efdeab2180035":[10,8,6,9,7],
 "structspa__io__clock.html#ab3d44cc4e16a47abd913553c3b977051":[10,8,6,9,0],
 "structspa__io__clock.html#ab639d1a64a22eecfa76ca04001bc163d":[10,8,6,9,1],
+"structspa__io__clock.html#ad5f6c0254efd87a20ca5807b577d3473":[10,8,6,9,10],
+"structspa__io__clock.html#ade3b0ef4306272d9a83a361ac3312cad":[10,8,6,9,12],
 "structspa__io__clock.html#af384237834c65792f29ccfd3fadfeefe":[10,8,6,9,5],
-"structspa__io__clock.html#af53218491c71ee19db11966bb16269ce":[10,8,6,9,9],
 "structspa__io__clock.html#af8fa38eef9a514c13306bd01da06e776":[10,8,6,9,6],
+"structspa__io__clock.html#af91526e984d8c9453e8b98c12dd1f500":[10,8,6,9,11],
 "structspa__io__latency.html":[10,8,6,11],
 "structspa__io__latency.html#a017f13089f0f6847cd70e62d725bd99c":[10,8,6,11,1],
 "structspa__io__latency.html#a5f23744c90a1dc0e9f0c1e067b8d390a":[10,8,6,11,2],
@@ -204,6 +232,7 @@ var NAVTREEINDEX20 =
 "structspa__loop__control__methods.html#a2d30cbd197ae33a77b5ccce2216ca61a":[10,8,9,4,7,5],
 "structspa__loop__control__methods.html#a4a64700ab318b03abb1a5ec5a5309f8a":[10,8,9,4,7,3],
 "structspa__loop__control__methods.html#a4af155a89512ec591bac117a3907e8c4":[10,8,9,4,7,2],
+"structspa__loop__control__methods.html#a6fd7cce6e454d8bbaff7f13d2035f6c9":[10,8,9,4,7,6],
 "structspa__loop__control__methods.html#a84177384a1a726c4b35a3e1d9bc8f30f":[10,8,9,4,7,4],
 "structspa__loop__control__methods.html#aa66e2f92b352ef1ae10b591f11086340":[10,8,9,4,7,0],
 "structspa__loop__methods.html":[10,8,9,4,5],
@@ -220,34 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__loop__utils__methods.html#a79ae6123ff0f20029d4e722053b49a11":[10,8,9,4,8,3],
 "structspa__loop__utils__methods.html#aa30b5933fcadb8606772d95471ec7a05":[10,8,9,4,8,6],
 "structspa__loop__utils__methods.html#ab24aa861875574691b833aaaf356a2ad":[10,8,9,4,8,7],
-"structspa__loop__utils__methods.html#abc9a0d7bb777e2c892343b1ca5a6d37d":[10,8,9,4,8,8],
-"structspa__loop__utils__methods.html#acb650a30486b87fcab5859afd000d913":[10,8,9,4,8,10],
-"structspa__loop__utils__methods.html#adc8b3b97121c94a824307117dad02989":[10,8,9,4,8,1],
-"structspa__loop__utils__methods.html#aea2ab7bb653eef26373295fafbe048fc":[10,8,9,4,8,5],
-"structspa__loop__utils__methods.html#aefb69d2a6ad30b352b4414401a55f3e7":[10,8,9,4,8,0],
-"structspa__loop__utils__methods.html#af9604ab5944fce7539516ff227ddc2f9":[10,8,9,4,8,9],
-"structspa__meta.html":[10,8,1,8],
-"structspa__meta.html#aad98af5fa0f07981e486b6268fe9c71c":[10,8,1,8,1],
-"structspa__meta.html#aceb2df955f0bee0bffaa59e62e6af67d":[10,8,1,8,0],
-"structspa__meta.html#ae2198fc30f4df8e624cd06db8cfe9583":[10,8,1,8,2],
-"structspa__meta__bitmap.html":[10,8,1,11],
-"structspa__meta__bitmap.html#a6f32bc13290f583d10ea16cc1bb825da":[10,8,1,11,1],
-"structspa__meta__bitmap.html#aa1f903801d658ae96cbc5e624676ff71":[10,8,1,11,0],
-"structspa__meta__bitmap.html#abaac271d52c056bf717f25698e9690bd":[10,8,1,11,3],
-"structspa__meta__bitmap.html#ac2f340dbebb61308461ac61592b52fe0":[10,8,1,11,2],
-"structspa__meta__busy.html":[10,8,1,14],
-"structspa__meta__busy.html#af5a282aa87b7c7b44900c00155ea77f4":[10,8,1,14,1],
-"structspa__meta__busy.html#afa6284c360957925babd30c58fdd4807":[10,8,1,14,0],
-"structspa__meta__control.html":[10,8,1,13],
-"structspa__meta__control.html#a906715cf9e6709fcd23de4aef7c1dd4a":[10,8,1,13,0],
-"structspa__meta__cursor.html":[10,8,1,12],
-"structspa__meta__cursor.html#a01ee3f6baba19d1a0851a44badd819a9":[10,8,1,12,1],
-"structspa__meta__cursor.html#a46bdd5e6f3d880a74ae602e596176028":[10,8,1,12,3],
-"structspa__meta__cursor.html#a5f190ab6e828890a8c5b530cb9cae78d":[10,8,1,12,0],
-"structspa__meta__cursor.html#a78b7805e66e52164fc8a985578b4c990":[10,8,1,12,2],
-"structspa__meta__cursor.html#a9785c5b1408d2d4c4cc053bfb67ef6c0":[10,8,1,12,4],
-"structspa__meta__header.html":[10,8,1,9],
-"structspa__meta__header.html#a1410208fd9ccdd153418f01d5ce12d7b":[10,8,1,9,1],
-"structspa__meta__header.html#a2d8eed1753e4b1649faf357f3307217d":[10,8,1,9,0],
-"structspa__meta__header.html#a76604c6ef39f2e3f103f6e71532205c8":[10,8,1,9,4]
+"structspa__loop__utils__methods.html#abc9a0d7bb777e2c892343b1ca5a6d37d":[10,8,9,4,8,8]
 };
